@@ -4,6 +4,7 @@ import sys
 import json
 import math
 import datetime
+import mimetypes
 import email.utils
 import traceback as _traceback
 from dateutil.tz import tzoffset, tzlocal
@@ -17,7 +18,7 @@ _SERVER = dict(os.environ)
 for k in list(_SERVER.keys()):
     if k.startswith("REDIRECT_"):
         _SERVER[k.replace("REDIRECT_", "")] = _SERVER[k]
-arguments = FieldStorage(environ=_SERVER)
+arguments = FieldStorage(environ=_SERVER, keep_blank_values=True)
 arguments = {k: [_.value for _ in arguments[k]] if isinstance(arguments[k], list) else arguments[k].value for k in arguments}
 _SERVER = HeadersDict(_SERVER)
 _GET = arguments
@@ -245,7 +246,7 @@ def generate_range_headers(fp, disposition: str = "inline"):
     except UnicodeEncodeError:
         filename = "filename*=utf-8''{}".format(encodeURIComponent(filename))
     set_header("Accept-Range", "bytes")
-    set_header("Content-Type", "application/octet-stream")
+    set_header("Content-Type", mimetypes.guess_type(filename) or "application/octet-stream")
     set_header("Content-Disposition", "{}; {}".format(disposition, filename))
     set_header("Content-Range", "bytes {}-{}/{}".format(range[0], range[1], size))
     set_header("Content-Length", str(length))
